@@ -159,13 +159,7 @@ def _stage_tree(path, fs, fs_info, name, odb=None, **kwargs):
             pass
 
     meta, tree = _build_tree(path, fs, name, odb=odb, **kwargs)
-    state = odb.state if odb and odb.state else None
-    hash_info = None
-    if state:
-        _, hash_info = state.get(  # pylint: disable=assignment-from-none
-            path, fs
-        )
-    tree.digest(hash_info=hash_info)
+    tree.digest()
     odb.add(tree.path, tree.fs, tree.oid, hardlink=False)
     raw = odb.get(tree.oid)
     # cleanup unneeded memfs tmpfile and return tree based on the
@@ -275,12 +269,6 @@ def stage(
         logger.debug("staged tree '%s'", obj)
         if name != "md5":
             obj = _stage_external_tree_info(odb, obj, name)
-
-        # In order to avoid re-building the tree when it is not committed to
-        # the local odb (e.g. for a status call), we save it as a raw object.
-        # Loading this instead of building the tree can speed up `dvc status`
-        # for modified directories, see #7390
-        odb.add(obj.path, obj.fs, obj.hash_info.as_raw().value)
     else:
         _, meta, obj = _stage_file(
             path,
